Thirdparty applications support
===============================

Here belongs some notes on thirdparty Django applications support in `siteblocks`.


django-modeltranslation
-----------------------

https://pypi.python.org/pypi/django-modeltranslation/

You can use `modeltranslation` to make your site blocks language dependent.

This will require setting `SITEBLOCKS_I18N_SUPPORT` to **True** in *settings.py* of your project.
